@@ -594,7 +594,7 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
     
     def _categorize_detections(self, detections: List[Dict], staff_categories: List[str],
                               customer_categories: List[str]) -> Tuple[List[Dict], List[Dict]]:
-        """Categorize detections into staff and customers, with persistent staff ID logic."""
+        """Categorize detections into staff and customers, with persistent staff ID logic. Only include detections whose category is in staff_categories or customer_categories."""
         staff_detections = []
         customer_detections = []
 
@@ -614,9 +614,7 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                     self.persistent_staff_ids.add(track_id)
             elif category in customer_categories:
                 customer_detections.append(detection)
-            else:
-                # Default to customer if category is unknown
-                customer_detections.append(detection)
+            # else: skip detection (do not add to either list)
 
         return staff_detections, customer_detections
     
