@@ -31,7 +31,7 @@ class ConcreteCrackConfig(BaseConfig):
     smoothing_confidence_range_factor: float = 0.5
 
     #confidence thresholds
-    confidence_threshold: float = 0.2
+    confidence_threshold: float = 0.6
 
     usecase_categories: List[str] = field(
         default_factory=lambda: ['Cracks']
@@ -45,7 +45,7 @@ class ConcreteCrackConfig(BaseConfig):
 
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
-            0: "Cracks",
+            0: "Cracks"
         }
     )
 
@@ -267,7 +267,7 @@ class ConcreteCrackUseCase(BaseProcessor):
                     smoothing_algorithm=config.smoothing_algorithm,
                     window_size=config.smoothing_window_size,
                     cooldown_frames=config.smoothing_cooldown_frames,
-                    confidence_threshold=config.confidence_threshold,  # Use concrete threshold as default
+                    confidence_threshold=config.confidence_threshold,  # Use mask threshold as default
                     confidence_range_factor=config.smoothing_confidence_range_factor,
                     enable_smoothing=True
                 )
@@ -408,7 +408,7 @@ class ConcreteCrackUseCase(BaseProcessor):
                     "max_value": 10,
                     "level_settings": {"info": 2, "warning": 5, "critical": 7}
                 },
-                "application_name": "Concrete Crack detection System",
+                "application_name": "concrete crack detection System",
                 "application_version": "1.2",
                 "location_info": None,
                 "human_text": human_text
