@@ -10,6 +10,7 @@ from typing import Any, Dict, List, Optional
 from dataclasses import asdict
 import time
 from datetime import datetime, timezone
+import copy  # Added for deep copying detections to preserve original masks
 
 from ..core.base import BaseProcessor, ProcessingContext, ProcessingResult, ConfigProtocol, ResultFormat
 from ..utils import (
@@ -252,21 +253,10 @@ class PotholeSegmentationUseCase(BaseProcessor):
         input_format = match_results_structure(data)
         context.input_format = input_format
         context.confidence_threshold = config.confidence_threshold
-
-        # Store original masks to preserve through all steps
-        original_detections = {id(det): det.get("masks", det.get("mask", [])) for det in data}
-        self.logger.debug(f"Input masks: {[det.get('masks', det.get('mask', [])) for det in data]}")
         
         # Step 1: Confidence filtering
         if config.confidence_threshold is not None:
             processed_data = filter_by_confidence(data, config.confidence_threshold)
-            # Restore masks
-            processed_data = [
-                {**det, "masks": original_detections.get(id(det), det.get("masks", det.get("mask", [])))}
-                for det in processed_data
-            ]
-            self.logger.debug(
-                f"Masks after confidence filtering: {[det.get('masks', det.get('mask', [])) for det in processed_data]}")
         else:
             processed_data = data
             self.logger.debug(f"Did not apply confidence filtering with threshold since nothing was provided")
@@ -274,26 +264,15 @@ class PotholeSegmentationUseCase(BaseProcessor):
         # Step 2: Apply category mapping if provided
         if config.index_to_category:
             processed_data = apply_category_mapping(processed_data, config.index_to_category)
-            # Restore masks
-            processed_data = [
-                {**det, "masks": original_detections.get(id(det), det.get("masks", det.get("mask", [])))}
-                for det in processed_data
-            ]
-            self.logger.debug(
-                f"Masks after category mapping: {[det.get('masks', det.get('mask', [])) for det in processed_data]}")
 
         # Step 3: Category filtering
         if config.target_categories:
             processed_data = [d for d in processed_data if d.get('category') in self.target_categories]
-            # Restore masks
-            processed_data = [
-                {**det, "masks": original_detections.get(id(det), det.get("masks", det.get("mask", [])))}
-                for det in processed_data
-            ]
-            self.logger.debug(
-                f"Masks after category filtering: {[det.get('masks', det.get('mask', [])) for det in processed_data]}")
 
         # Step 4: Apply bbox smoothing if enabled
+        # Deep-copy detections so that we preserve the original masks before any
+        # smoothing/tracking logic potentially removes them.
+        raw_processed_data = [copy.deepcopy(det) for det in processed_data]
         if config.enable_smoothing:
             if self.smoothing_tracker is None:
                 smoothing_config = BBoxSmoothingConfig(
@@ -305,16 +284,9 @@ class PotholeSegmentationUseCase(BaseProcessor):
                     enable_smoothing=True
                 )
                 self.smoothing_tracker = BBoxSmoothingTracker(smoothing_config)
-            # Store masks before smoothing
-            pre_smoothing_detections = {id(det): det.get("masks", det.get("mask", [])) for det in processed_data}
+           
             processed_data = bbox_smoothing(processed_data, self.smoothing_tracker.config, self.smoothing_tracker)
             # Restore masks after smoothing
-            processed_data = [
-                {**det, "masks": pre_smoothing_detections.get(id(det), det.get("masks", det.get("mask", [])))}
-                for det in processed_data
-            ]
-            self.logger.debug(
-                f"Masks after smoothing: {[det.get('masks', det.get('mask', [])) for det in processed_data]}")
 
         # Step 5: Advanced tracking (BYTETracker-like)
         try:
@@ -326,18 +298,8 @@ class PotholeSegmentationUseCase(BaseProcessor):
                 tracker_config = TrackerConfig()
                 self.tracker = AdvancedTracker(tracker_config)
                 self.logger.info("Initialized AdvancedTracker for Monitoring and tracking")
-
-            # Store masks before tracking
-            pre_tracking_detections = {id(det): det.get("masks", det.get("mask", [])) for det in processed_data}
+           
             processed_data = self.tracker.update(processed_data)
-            # Restore masks after tracking
-            processed_data = [
-                {**det, "masks": pre_tracking_detections.get(id(det), det.get("masks", det.get("mask", [])))}
-                for det in processed_data
-            ]
-            self.logger.debug(
-                f"Masks after tracking: {[det.get('masks', det.get('mask', [])) for det in processed_data]}")
-
         except Exception as e:
             # If advanced tracker fails, fallback to unsmoothed detections
             self.logger.warning(f"AdvancedTracker failed: {e}")
@@ -345,6 +307,14 @@ class PotholeSegmentationUseCase(BaseProcessor):
         # Update tracking state for total count per label
         self._update_tracking_state(processed_data)
 
+        # ------------------------------------------------------------------ #
+        # Re-attach segmentation masks that were present in the original input
+        # but may have been stripped during smoothing/tracking. We match each
+        # processed detection back to the raw detection with the highest IoU
+        # and copy over its "masks" field (if available).
+        # ------------------------------------------------------------------ #
+        processed_data = self._attach_masks_to_detections(processed_data, raw_processed_data)
+
         # Update frame counter
         self._total_frame_counter += 1
 
@@ -364,8 +334,7 @@ class PotholeSegmentationUseCase(BaseProcessor):
         # Add total unique counts after tracking using only local state
         total_counts = self.get_total_counts()
         counting_summary['total_counts'] = total_counts
-        print("DEBUGGGGGGGGGGGGGGG2")
-        print(processed_data)
+
         insights = self._generate_insights(counting_summary, config)
         alerts = self._check_alerts(counting_summary, config)
         predictions = self._extract_predictions(processed_data)
@@ -618,6 +587,61 @@ class PotholeSegmentationUseCase(BaseProcessor):
             "detections": valid_detections
         }
 
+    # ------------------------------------------------------------------ #
+    # Helper to merge masks back into detections                        #
+    # ------------------------------------------------------------------ #
+    def _attach_masks_to_detections(
+        self,
+        processed_detections: List[Dict[str, Any]],
+        raw_detections: List[Dict[str, Any]],
+        iou_threshold: float = 0.5,
+    ) -> List[Dict[str, Any]]:
+        """
+        Attach segmentation masks from the original `raw_detections` list to the
+        `processed_detections` list returned after smoothing/tracking.
+
+        Matching between detections is performed using Intersection-over-Union
+        (IoU) of the bounding boxes. For each processed detection we select the
+        raw detection with the highest IoU above `iou_threshold` and copy its
+        `masks` (or `mask`) field. If no suitable match is found, the detection
+        keeps an empty list for `masks` to maintain a consistent schema.
+        """
+
+        if not processed_detections or not raw_detections:
+            # Nothing to do – ensure masks key exists for downstream logic.
+            for det in processed_detections:
+                det.setdefault("masks", [])
+            return processed_detections
+
+        # Track which raw detections have already been matched to avoid
+        # assigning the same mask to multiple processed detections.
+        used_raw_indices = set()
+
+        for det in processed_detections:
+            best_iou = 0.0
+            best_idx = None
+
+            for idx, raw_det in enumerate(raw_detections):
+                if idx in used_raw_indices:
+                    continue
+
+                iou = self._compute_iou(det.get("bounding_box"), raw_det.get("bounding_box"))
+                if iou > best_iou:
+                    best_iou = iou
+                    best_idx = idx
+
+            if best_idx is not None and best_iou >= iou_threshold:
+                raw_det = raw_detections[best_idx]
+                masks = raw_det.get("masks", raw_det.get("mask"))
+                if masks is not None:
+                    det["masks"] = masks
+                used_raw_indices.add(best_idx)
+            else:
+                # No adequate match – default to empty list to keep schema consistent.
+                det.setdefault("masks", ["EMPTY"])
+
+        return processed_detections
+
     # Human-friendly display names for  categories
     CATEGORY_DISPLAY = {
         "pothole": "pothole"
